@@ -1,23 +1,23 @@
 #![doc = include_str!("../README.md")]
 
 pub mod column;
-pub(crate) mod common;
+pub(crate) mod overflow;
 pub mod row;
-pub(crate) mod scroll;
 pub mod spacer;
 
 pub use css_style;
 
 // components
 pub use column::Column;
+pub use overflow::Overflow;
 pub use row::Row;
 pub use spacer::Spacer;
 
 // types
 pub use css_style::box_align::AlignSelf;
+pub use css_style::size::Length;
 pub use css_style::AlignContent as AlignColumns;
 pub use css_style::AlignContent as AlignRows;
 pub use css_style::AlignItems as CrossAlign;
 pub use css_style::JustifyContent as Align;
-pub use css_style::{Gap, Margin, Padding};
-pub use scroll::Scroll;
+pub use css_style::{Background, Border, BoxShadow as Shadow, Gap, Margin, Padding};
